@@ -17,12 +17,14 @@ import re
 import yaml
 import collections
 
+from agml.framework import AgMLSerializable
 import agml.utils.logging as logging
 from agml.utils.data import (
     load_public_sources, load_citation_sources, maybe_you_meant, copyright_print
 )
 
-class DatasetMetadata(object):
+
+class DatasetMetadata(AgMLSerializable):
     """Stores metadata about a certain AgML dataset.
 
     When loading in a dataset using the `AgMLDataLoader`, the "info"
@@ -46,6 +48,8 @@ class DatasetMetadata(object):
     property of this class, but any additional info that is not can
     be accessed by treating the `info` object as a dictionary.
     """
+    serializable = frozenset(('name', 'metadata', 'citation_meta'))
+
     def __init__(self, name):
         self._load_source_info(name)
 
@@ -55,6 +59,9 @@ class DatasetMetadata(object):
     def __str__(self):
         return self._name
 
+    def __fspath__(self):
+        return self._name
+
     def __eq__(self, other):
         if isinstance(other, DatasetMetadata):
             return self._name == other._name
@@ -66,6 +73,9 @@ class DatasetMetadata(object):
 
     def _load_source_info(self, name):
         """Loads the data source metadata into the class."""
+        if isinstance(name, DatasetMetadata):
+            name = name.name
+
         source_info = load_public_sources()
         if name not in source_info.keys():
             if name.replace('-', '_') not in source_info.keys():
@@ -115,6 +125,13 @@ class DatasetMetadata(object):
         continent, country = self._metadata['location'].values()
         return Location(continent = continent, country = country)
 
+    @property
+    def image_stats(self):
+        """Returns the mean and standard deviation of the RGB images."""
+        ImageStats = collections.namedtuple('ImageStats', ['mean', 'std'])
+        mean, std = self._metadata['stats'].values()
+        return ImageStats(mean = mean, std = std)
+
     @property
     def sensor_modality(self):
         return self._metadata['sensor_modality']
